@@ -1,8 +1,8 @@
-import enum
 import typing
 
 from qtpy import QtWidgets, QtCore, QtGui
 
+from .constants import RibbonCategoryStyle
 from .panel import RibbonPanel
 from .separator import RibbonSeparator
 from .utils import DataFile
@@ -11,28 +11,6 @@ if typing.TYPE_CHECKING:
     from .ribbonbar import RibbonBar  # noqa: F401
 
 
-class RibbonCategoryStyle(enum.IntEnum):
-    """The button style of a category."""
-
-    Normal = 0
-    Context = 1
-
-
-Normal = RibbonCategoryStyle.Normal
-Context = RibbonCategoryStyle.Context
-
-
-#: A list of context category colors
-contextColors = [
-    QtGui.QColor(201, 89, 156),  # 玫红
-    QtGui.QColor(242, 203, 29),  # 黄
-    QtGui.QColor(255, 157, 0),  # 橙
-    QtGui.QColor(14, 81, 167),  # 蓝
-    QtGui.QColor(228, 0, 69),  # 红
-    QtGui.QColor(67, 148, 0),  # 绿
-]
-
-
 class RibbonCategoryLayoutButton(QtWidgets.QToolButton):
     """Previous/Next buttons in the category when the
     size is not enough for the widgets.
@@ -216,8 +194,6 @@ class RibbonCategory(RibbonCategoryLayoutWidget):
         self._ribbon = parent  # type: RibbonBar
         self._color = color
 
-        super().__init__(parent)
-
     def setMaximumRows(self, rows: int):
         """Set the maximum number of rows.
 
