@@ -1,31 +1,15 @@
 import typing
-from enum import IntEnum
 
 from qtpy import QtWidgets, QtCore, QtGui
 
-from .category import (
-    RibbonCategory,
-    RibbonContextCategory,
-    RibbonNormalCategory,
-    RibbonCategoryStyle,
-    contextColors,
-    RibbonContextCategories,
-)
+from .category import RibbonCategory, RibbonContextCategory, RibbonNormalCategory, RibbonContextCategories
+from .constants import RibbonStyle, RibbonCategoryStyle, contextColors
 from .menu import RibbonMenu
 from .tabbar import RibbonTabBar
 from .titlewidget import RibbonTitleWidget, RibbonApplicationButton
 from .utils import DataFile
 
 
-class RibbonStyle(IntEnum):
-    Default = 0
-    Debug = 1
-
-
-Debug = RibbonStyle.Debug
-Default = RibbonStyle.Default
-
-
 class RibbonStackedWidget(QtWidgets.QStackedWidget):
     """Stacked widget that is used to display the ribbon."""
 
@@ -46,6 +30,9 @@ class RibbonBar(QtWidgets.QMenuBar):
     #: Signal, the help button was clicked.
     helpButtonClicked = QtCore.Signal(bool)
 
+    #: hide the ribbon bar automatically when the mouse press outside the ribbon bar
+    _autoHideRibbon = False
+
     #: The categories of the ribbon.
     _categories: typing.Dict[str, RibbonCategory] = {}
     _contextCategoryCount = 0
@@ -107,6 +94,18 @@ class RibbonBar(QtWidgets.QMenuBar):
         self._titleWidget.tabBar().currentChanged.connect(self.showCategoryByIndex)  # type: ignore
         self.setRibbonStyle(RibbonStyle.Default)
 
+    def setAutoHideRibbon(self, autoHide: bool):
+        """Set whether the ribbon bar is automatically hidden when the mouse is pressed outside the ribbon bar.
+
+        :param autoHide: Whether the ribbon bar is automatically hidden.
+        """
+        self._autoHideRibbon = autoHide
+
+    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
+        if self._autoHideRibbon and a1.type() == QtCore.QEvent.HoverMove:
+            self.setRibbonVisible(self.underMouse())
+        return super().eventFilter(a0, a1)
+
     def actionAt(self, QPoint):
         raise NotImplementedError("RibbonBar.actionAt() is not implemented in the ribbon bar.")
 
