@@ -277,3 +277,16 @@ class RibbonTitleWidget(QtWidgets.QFrame):
         :return: The collapse ribbon button.
         """
         return self._collapseRibbonButton
+
+    # 标题栏拖动
+    def mousePressEvent(self, e):
+        self.start_point = e.globalPos()
+        self.window_point = self.parentWidget().parentWidget().frameGeometry().topLeft()
+
+    def mouseMoveEvent(self, e):
+        relpos = e.globalPos() - self.start_point
+        self.parentWidget().parentWidget().move(self.window_point + relpos)
+
+    def mouseDoubleClickEvent(self, e):
+        mainwindow = self.parentWidget().parentWidget()
+        mainwindow.showNormal() if mainwindow.isMaximized() else mainwindow.showMaximized()
